@@ -12,9 +12,6 @@
 --
 -----------------------------------------------------------------------------
 
-{-# LANGUAGE FlexibleInstances #-}
-{-# OPTIONS_GHC -fno-warn-orphans #-}
-
 module Text.Parsec.String
     ( Parser, GenParser, parseFromFile
     ) where
@@ -22,11 +19,6 @@ module Text.Parsec.String
 import Text.Parsec.Error
 import Text.Parsec.Prim
 
-instance (Monad m) => Stream [tok] m tok where
-    uncons []     = return $ Nothing
-    uncons (t:ts) = return $ Just (t,ts)
-    {-# INLINE uncons #-}
-
 type Parser = Parsec String ()
 type GenParser tok st = Parsec [tok] st
 
